@@ -59,7 +59,10 @@ static int spcr_test1(fwts_framework *fw)
 	bool pci = true;
 	bool passed = true;
 
-	/* Assuming revision 2 */
+	/*
+	 * Assuming revision 2, full list from
+	 * http://go.microsoft.com/fwlink/p/?LinkId=234837)
+	 */
 	switch (spcr->interface_type) {
 	case 0x00:
 		str = "16550 compatible";
@@ -75,13 +78,25 @@ static int spcr_test1(fwts_framework *fw)
 		str = "Reserved (Do not Use)";
 		reserved = true;
 		break;
+	case 0x0d:
+		str = "(deprecated) ARM SBSA";
+		break;
+	case 0x0e:
+		str = "ARM SBSA Generic UART";
+		break;
+	case 0x0f:
+		str = "ARM DCC";
+		break;
+	case 0x10:
+		str = "BCM2835";
+		break;
 	default:
 		str = "Reserved";
 		reserved = true;
 		break;
 	}
 
-	fwts_log_info_verbatum(fw, "Serial Interface: %s", str);
+	fwts_log_info_verbatim(fw, "Serial Interface: %s", str);
 	if (reserved) {
 		passed = false;
 		fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -151,7 +166,7 @@ static int spcr_test1(fwts_framework *fw)
 		str = "Reserved";
 		reserved = true;
 	}
-	fwts_log_info_verbatum(fw, "Baud Rate:        %s", str);
+	fwts_log_info_verbatim(fw, "Baud Rate:        %s", str);
 	if (reserved) {
 		passed = false;
 		fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -203,7 +218,7 @@ static int spcr_test1(fwts_framework *fw)
 		str = "Reserved";
 		reserved = true;
 	}
-	fwts_log_info_verbatum(fw, "Terminal Type:    %s", str);
+	fwts_log_info_verbatim(fw, "Terminal Type:    %s", str);
 	if (reserved) {
 		passed = false;
 		fwts_failed(fw, LOG_LEVEL_HIGH,
