@@ -187,6 +187,8 @@ static char                *TableEvents[] =
 {
     "LOAD",
     "UNLOAD",
+    "INSTALL",
+    "UNINSTALL",
     "UNKNOWN"
 };
 #endif /* !ACPI_REDUCED_HARDWARE */
