@@ -27,15 +27,17 @@
 #include "fwts.h"
 
 static const char op_powernv[] = "ibm,powernv";
+static const char opal_firmware[] = "/ibm,opal/firmware";
+static const char platform_firmware[] = "/ibm,firmware-versions";
 
 static const char *firestone_models[] = {
-	"8335-GTA        ",
-	"8335-GCA        ",
-	"8335-GTX        ",
+	"8335-GTA",
+	"8335-GCA",
+	"8335-GTX",
 };
 
 static const char *garrison_models[] = {
-	"8335-GTB        ",
+	"8335-GTB",
 };
 
 static struct reference_platform {
@@ -49,49 +51,95 @@ static struct reference_platform {
 		FWTS_ARRAY_LEN(garrison_models)},
 };
 
-static int check_property_printable(fwts_framework *fw,
-	const char *name,
-	const char *buf,
-	size_t len)
+
+static int dt_sysinfo_get_version(fwts_framework *fw,
+				int node,
+				char *firmware)
 {
-	bool printable = true;
-	unsigned int i;
+	int version_len;
+	const char *version_buf;
 
-	/* we need at least one character plus a nul */
-	if (len < 2) {
-		fwts_failed(fw, LOG_LEVEL_LOW,
-			"DTPrintablePropertyShort",
-			"property %s is too short", name);
+	/* only output if the platform_firmware node is present */
+	if (node >= 0) {
+                version_buf = fdt_getprop(fw->fdt, node,
+                        firmware, &version_len);
+                if (version_buf) {
+                        fwts_passed(fw,
+                                "OPAL \"%s\" firmware version from device"
+				" tree node \"%s\" is \"%s\".",
+                                firmware, platform_firmware, version_buf);
+                } else {
+                        fwts_failed(fw, LOG_LEVEL_CRITICAL,
+				"DTSysInfoCheck",
+                                "OPAL \"%s\" firmware version from device"
+				" tree node \"%s\" was not found,"
+                                " check your installation for"
+                                " device tree node \"%s\".", platform_firmware,
+				firmware, platform_firmware);
+                }
+	}
+	return FWTS_OK;
+}
+
+static int dt_sysinfo_check_version(fwts_framework *fw)
+{
+	if (!fw->fdt) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"DTMissing",
+			"Device tree is missing, check your installation.");
+		return FWTS_ABORTED;
+	}
+
+	int node, version_len;
+	const char *version_buf;
+
+	fwts_log_info(fw,
+		"OPAL base device tree path is %s.",
+		DT_FS_PATH);
+	node = fdt_path_offset(fw->fdt,
+			opal_firmware);
+	if (node >= 0) {
+		version_buf = fdt_getprop(fw->fdt, node,
+			"version", &version_len);
+		if (version_buf) {
+			fwts_passed(fw,
+				"OPAL Firmware version from device tree node"
+				" \"%s\" is \"%s\".",
+				opal_firmware, version_buf);
+		} else {
+			fwts_failed(fw, LOG_LEVEL_CRITICAL,
+				"DTSysInfoCheck",
+				"OPAL Firmware version from device tree node"
+				" \"%s\" was not found,"
+				" check your installation for"
+				" device tree node \"%s\" property"
+				" \"version\".",
+				opal_firmware, opal_firmware);
+		}
+	} else {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"DTMissing",
+			"Device tree missing version property of \"%s\", "
+			"check your installation for device tree node"
+			" property \"version\".",
+			opal_firmware);
 		return FWTS_ERROR;
 	}
 
-	/* check all characters are printable */
-	for (i = 0; i < len - 1; i++) {
-		printable = printable && isprint(buf[i]);
-		if (!printable)
-			break;
-	}
+	/* Now check for additional firmware versions */
 
-	if (!printable) {
-		fwts_failed(fw, LOG_LEVEL_LOW,
-			"DTPrintablePropertyInvalid",
-			"property %s contains unprintable characters",
-			name);
-		return FWTS_ERROR;
-	}
+	node = fdt_path_offset(fw->fdt,
+			platform_firmware);
 
-	/* check for a trailing nul */
-	if (buf[len-1] != '\0') {
-		fwts_failed(fw, LOG_LEVEL_LOW,
-			"DTPrintablePropertyNoNul",
-			"property %s isn't nul-terminated", name);
-		return FWTS_ERROR;
-	}
-
-	fwts_log_info_verbatim(fw,
-		"DTPrintableProperty with a string"
-		" value of \"%s\" passed",
-		buf);
+	dt_sysinfo_get_version(fw, node, "occ");
+	dt_sysinfo_get_version(fw, node, "open-power");
+	dt_sysinfo_get_version(fw, node, "linux");
+	dt_sysinfo_get_version(fw, node, "skiboot");
+	dt_sysinfo_get_version(fw, node, "capp-ucode");
+	dt_sysinfo_get_version(fw, node, "hostboot-binaries");
+	dt_sysinfo_get_version(fw, node, "hostboot");
+	dt_sysinfo_get_version(fw, node, "petitboot");
+	dt_sysinfo_get_version(fw, node, "buildroot");
 
 	return FWTS_OK;
 }
@@ -105,23 +153,25 @@ static int dt_sysinfo_check_root_property(
 	const char *buf;
 
 	if (!fw->fdt) {
-		fwts_failed(fw, LOG_LEVEL_LOW, "DTMissing",
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"DTMissing",
 			"Device Tree is missing, aborting");
 		return FWTS_ABORTED;
 	}
 
 	node = fdt_path_offset(fw->fdt, "/");
 	if (node < 0) {
-		fwts_failed(fw, LOG_LEVEL_LOW, "DTRootNodeMissing",
-				"root device tree node is missing");
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"DTRootNodeMissing",
+			"root device tree node is missing");
 		return FWTS_ERROR;
 	}
 
 	buf = fdt_getprop(fw->fdt, node, name, &len);
 	if (buf == NULL) {
-		fwts_failed(fw, LOG_LEVEL_LOW,
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
 			"DTSysinfoPropertyMissing",
-			"can't read property %s: %s",
+			"Cannot read property %s: %s",
 			name, fdt_strerror(len));
 		return FWTS_ERROR;
 	}
@@ -131,7 +181,7 @@ static int dt_sysinfo_check_root_property(
 			return FWTS_ERROR; /* failures logged prior */
 	}
 
-	fwts_passed(fw, "sysinfo property %s is valid", name);
+	fwts_passed(fw, "sysinfo property \"%s\" is valid", name);
 
 	return FWTS_OK;
 }
@@ -221,18 +271,21 @@ static int dt_sysinfo_check_ref_plat_compatible(fwts_framework *fw)
 
 	node = fdt_path_offset(fw->fdt, "/");
 	if (node < 0) {
-		fwts_failed(fw, LOG_LEVEL_HIGH, "DTRootNodeMissing",
+		fwts_failed(fw, LOG_LEVEL_HIGH,
+			"DTRootNodeMissing",
 			"root device tree node is missing");
 		return FWTS_ERROR;
 	}
 	if (fdt_node_check_compatible(fw->fdt, node, op_powernv)) {
-		fwts_failed(fw, LOG_LEVEL_HIGH, "DTCompatibleMissing",
+		fwts_failed(fw, LOG_LEVEL_HIGH,
+			"DTCompatibleMissing",
 			"DeviceTree failed validation, could not find"
 			" the \"compatible\" property of \"%s\" in the "
 			"root of the device tree", "ibm,powernv");
 		return FWTS_ERROR;
 	} else {
 		const char *model_buf, *compat_buf;
+		char *orig_model_buf, *tmp_model_buf;
 
 		compat_buf = fdt_getprop(fw->fdt, node,
 				"compatible", &compat_len);
@@ -241,35 +294,77 @@ static int dt_sysinfo_check_ref_plat_compatible(fwts_framework *fw)
 
 		if (!model_buf || !compat_buf) {
 			fwts_failed(fw,LOG_LEVEL_HIGH,
-				"DTSysinfoPropertyMissing",
-				"can't read properties for OpenPOWER"
+				"DTSysInfoCheck",
+				"Cannot read the properties for OpenPOWER"
 				" Reference Compatible check");
 			return FWTS_ERROR;
 		}
 
+		/* need modifiable memory    */
+		/* save original ptr to free */
+		tmp_model_buf = orig_model_buf = strdup(model_buf);
+		if (!tmp_model_buf) {
+			fwts_failed(fw, LOG_LEVEL_HIGH,
+				"DTSysInfoCheck",
+				"Unable to get memory for model"
+				" compare for OpenPOWER"
+				" Reference Compatible check");
+			return FWTS_ERROR;
+		}
+
+		tmp_model_buf = hidewhitespace(tmp_model_buf);
+		if (!(strcmp(model_buf, tmp_model_buf) == 0)) {
+			fwts_warning(fw,
+				"DTSysInfoCheck"
+				" See further advice in the log.");
+			fwts_log_nl(fw);
+			fwts_log_info_verbatim(fw,
+				"DTSysInfoCheck"
+				" Check the root \"model\" property"
+				" from the device tree %s \"%s\".",
+				DT_FS_PATH,
+				model_buf);
+			fwts_advice(fw,
+				"Check the root \"model\" property"
+				" from the device tree %s, "
+				"there are whitespace inconsistentencies"
+				" between the \"model\" property and "
+				" the trimmed value of \"%s\", report"
+				" this as a possible bug."
+				"  Run \"hexdump -C model\""
+				" from the \"%s\" directory to view"
+				" the raw contents of the property.",
+				DT_FS_PATH,
+				tmp_model_buf,
+				DT_FS_PATH);
+		}
 		if (machine_matches_reference_model(fw,
 				compat_buf,
 				compat_len,
-				model_buf)) {
+				tmp_model_buf)) {
 			fwts_passed(fw, "OpenPOWER Reference "
 				"Compatible passed");
 		} else {
 			fwts_failed(fw, LOG_LEVEL_HIGH,
 				"DTOpenPOWERReferenceFailed",
-			"Unable to find an OpenPOWER supported"
-			" match");
+				"Unable to find an OpenPOWER supported"
+				" match");
 			/* adding verbatim to show proper string */
 			fwts_log_info_verbatim(fw,
 			"Unable to find an OpenPOWER reference"
-			" match for \"%s\"", model_buf);
+			" match for \"%s\"", tmp_model_buf);
+			free(orig_model_buf);
 			return FWTS_ERROR;
 		}
+		free(orig_model_buf);
 	}
 
 	return FWTS_OK;
 }
 
 static fwts_framework_minor_test dt_sysinfo_tests[] = {
+	{ dt_sysinfo_check_version,
+		"Check firmware versions" },
 	{ dt_sysinfo_check_model,
 		"Check model property" },
 	{ dt_sysinfo_check_system_id,
